tonalanalysistools.RootlessChordClass
=====================================

.. abjad-lineage:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass

.. autoclass:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.cardinality
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.count
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.custom_identifier
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.extent
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.extent_name
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.from_interval_class_segment
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.from_selection
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.has_duplicates
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.index
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.inversion
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.item_class
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.position
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.quality_string
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.rotate
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.rotation
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.slope
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.spread
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__add__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__contains__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__eq__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__format__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__getitem__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__getslice__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__hash__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__iter__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__len__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__makenew__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__mul__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__ne__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__repr__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__rmul__
      ~abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__str__

Bases
-----

- :py:class:`pitchtools.IntervalSegment <abjad.tools.pitchtools.IntervalSegment.IntervalSegment>`

- :py:class:`pitchtools.Segment <abjad.tools.pitchtools.Segment.Segment>`

- :py:class:`datastructuretools.TypedTuple <abjad.tools.datastructuretools.TypedTuple.TypedTuple>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.cardinality
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.extent
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.extent_name
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.has_duplicates
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.inversion
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.item_class
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.position
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.quality_string
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.rotation
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.slope
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.spread
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.custom_identifier
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.count
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.index
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.rotate
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.from_selection
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.from_interval_class_segment
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__add__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__contains__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__format__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__getitem__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__getslice__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__hash__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__iter__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__len__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__makenew__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__mul__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__rmul__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RootlessChordClass.RootlessChordClass.__str__
   :noindex:
